curling_tee_line())
and the centre line (see curling_centre_line())The inner-most of the concentric circles comprising the house is called the
button. This is the intersection of the tee line (see curling_tee_line())
and the centre line (see curling_centre_line())
curling_button(feature_radius = 0)A data frame containing the bounding coordinates of the button
The radius of the button