lacrosse_offensive_zone(), lacrosse_defensive_zone(), and
lacrosse_neutral_zone(). This line may not stretch the entire width of the
field, so a parameter is created insteadThe center line divides the field of play into two equal halves, which are
generated via lacrosse_offensive_zone(), lacrosse_defensive_zone(), and
lacrosse_neutral_zone(). This line may not stretch the entire width of the
field, so a parameter is created instead
lacrosse_center_line(center_line_width = 0, line_thickness = 0)A data frame containing the bounding coordinates of the center line
The width of the center line (distance in y)
The thickness of the center line