lacrosse_defensive_area_line())The restraining line spans the entire width of the field (where present) and
connects to the defensive area lines (see lacrosse_defensive_area_line())
lacrosse_restraining_line(field_width = 0, line_thickness = 0)A data frame containing the bounding coordinates of the restraining line
The width of the field
The thickness of the restraining line